pub struct EncounterFrame {
pub x_hat: [f64; 3],
pub y_hat: [f64; 3],
pub z_hat: [f64; 3],
pub relative_position_km: [f64; 3],
pub relative_velocity_km_s: [f64; 3],
pub miss_km: f64,
pub relative_speed_km_s: f64,
}Expand description
Orthonormal encounter frame and the relative state it was built from.
Axes: x_hat is the in-plane cross-track axis, y_hat is along the
relative velocity, and z_hat is the encounter-plane normal.
Fields
x_hat: [f64; 3]y_hat: [f64; 3]z_hat: [f64; 3]relative_position_km: [f64; 3]relative_velocity_km_s: [f64; 3]miss_km: f64relative_speed_km_s: f64Trait Implementations
Sourceimpl Clone for EncounterFrame
impl Clone for EncounterFrame
Sourcefn clone(&self) -> EncounterFrame
fn clone(&self) -> EncounterFrame
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for EncounterFrame
Sourceimpl Debug for EncounterFrame
impl Debug for EncounterFrame
Sourceimpl PartialEq for EncounterFrame
impl PartialEq for EncounterFrame
Sourcefn eq(&self, other: &EncounterFrame) -> bool
fn eq(&self, other: &EncounterFrame) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EncounterFrame