pub enum CrossingDirection {
Rising,
Falling,
}Expand description
Direction of a threshold crossing.
Variants
Rising
Scalar value crossed from below the threshold to at or above it.
Falling
Scalar value crossed from at or above the threshold to below it.