pub struct EventFinder { /* private fields */ }Expand description
Uniform-scan event finder over a finite time window.
Implementations
Sourceimpl EventFinder
impl EventFinder
Sourcepub fn new(
start_seconds: f64,
end_seconds: f64,
step_seconds: f64,
time_tolerance_seconds: f64,
) -> Result<Self, EventFinderError>
pub fn new( start_seconds: f64, end_seconds: f64, step_seconds: f64, time_tolerance_seconds: f64, ) -> Result<Self, EventFinderError>
Construct an event finder over [start_seconds, end_seconds].
Sourcepub fn start_seconds(self) -> f64
pub fn start_seconds(self) -> f64
Start of the search window.
Sourcepub fn end_seconds(self) -> f64
pub fn end_seconds(self) -> f64
End of the search window.
Sourcepub fn step_seconds(self) -> f64
pub fn step_seconds(self) -> f64
Uniform coarse-scan step.
Sourcepub fn time_tolerance_seconds(self) -> f64
pub fn time_tolerance_seconds(self) -> f64
Event-time refinement tolerance.
Sourcepub fn find_crossings<P>(
self,
predicate: P,
threshold: f64,
) -> Result<Vec<CrossingEvent>, EventFinderError>where
P: ScalarEventPredicate,
pub fn find_crossings<P>(
self,
predicate: P,
threshold: f64,
) -> Result<Vec<CrossingEvent>, EventFinderError>where
P: ScalarEventPredicate,
Find refined threshold crossings of a scalar predicate.
Sourcepub fn find_crossings_batch_serial<P>(
self,
predicates: &[P],
threshold: f64,
) -> Vec<Result<Vec<CrossingEvent>, EventFinderError>>where
P: ScalarEventPredicate,
pub fn find_crossings_batch_serial<P>(
self,
predicates: &[P],
threshold: f64,
) -> Vec<Result<Vec<CrossingEvent>, EventFinderError>>where
P: ScalarEventPredicate,
Find threshold crossings for a batch of scalar predicates, serially.
Result element i belongs to predicates[i].
Sourcepub fn find_crossings_batch_parallel<P>(
self,
predicates: &[P],
threshold: f64,
) -> Vec<Result<Vec<CrossingEvent>, EventFinderError>>where
P: ScalarEventPredicate + Sync,
pub fn find_crossings_batch_parallel<P>(
self,
predicates: &[P],
threshold: f64,
) -> Vec<Result<Vec<CrossingEvent>, EventFinderError>>where
P: ScalarEventPredicate + Sync,
Find threshold crossings for a batch of scalar predicates in parallel.
Each predicate is evaluated by the same kernel as
EventFinder::find_crossings. The indexed collect preserves input
order, so result element i belongs to predicates[i].
Sourcepub fn find_extrema<P>(
self,
predicate: P,
) -> Result<Vec<ExtremumEvent>, EventFinderError>where
P: ScalarEventPredicate,
pub fn find_extrema<P>(
self,
predicate: P,
) -> Result<Vec<ExtremumEvent>, EventFinderError>where
P: ScalarEventPredicate,
Find refined local maxima and minima of a scalar predicate.
Sourcepub fn find_extrema_batch_serial<P>(
self,
predicates: &[P],
) -> Vec<Result<Vec<ExtremumEvent>, EventFinderError>>where
P: ScalarEventPredicate,
pub fn find_extrema_batch_serial<P>(
self,
predicates: &[P],
) -> Vec<Result<Vec<ExtremumEvent>, EventFinderError>>where
P: ScalarEventPredicate,
Find local extrema for a batch of scalar predicates, serially.
Result element i belongs to predicates[i].
Sourcepub fn find_extrema_batch_parallel<P>(
self,
predicates: &[P],
) -> Vec<Result<Vec<ExtremumEvent>, EventFinderError>>where
P: ScalarEventPredicate + Sync,
pub fn find_extrema_batch_parallel<P>(
self,
predicates: &[P],
) -> Vec<Result<Vec<ExtremumEvent>, EventFinderError>>where
P: ScalarEventPredicate + Sync,
Find local extrema for a batch of scalar predicates in parallel.
Each predicate is evaluated by the same kernel as
EventFinder::find_extrema. The indexed collect preserves input order,
so result element i belongs to predicates[i].
Sourcepub fn find_state_changes<P>(
self,
predicate: P,
) -> Result<Vec<StateChangeEvent>, EventFinderError>where
P: DiscreteEventPredicate,
pub fn find_state_changes<P>(
self,
predicate: P,
) -> Result<Vec<StateChangeEvent>, EventFinderError>where
P: DiscreteEventPredicate,
Find refined changes of a boolean state predicate.
Sourcepub fn find_state_changes_batch_serial<P>(
self,
predicates: &[P],
) -> Vec<Result<Vec<StateChangeEvent>, EventFinderError>>where
P: DiscreteEventPredicate,
pub fn find_state_changes_batch_serial<P>(
self,
predicates: &[P],
) -> Vec<Result<Vec<StateChangeEvent>, EventFinderError>>where
P: DiscreteEventPredicate,
Find state changes for a batch of discrete predicates, serially.
Result element i belongs to predicates[i].
Sourcepub fn find_state_changes_batch_parallel<P>(
self,
predicates: &[P],
) -> Vec<Result<Vec<StateChangeEvent>, EventFinderError>>where
P: DiscreteEventPredicate + Sync,
pub fn find_state_changes_batch_parallel<P>(
self,
predicates: &[P],
) -> Vec<Result<Vec<StateChangeEvent>, EventFinderError>>where
P: DiscreteEventPredicate + Sync,
Find state changes for a batch of discrete predicates in parallel.
Each predicate is evaluated by the same kernel as
EventFinder::find_state_changes. The indexed collect preserves input
order, so result element i belongs to predicates[i].