ForceModelComponents

Struct ForceModelComponents 

pub struct ForceModelComponents {
    pub two_body_mu_km3_s2: Option<f64>,
    pub zonal: Option<ZonalGravity>,
    pub spherical_harmonic: Option<SphericalHarmonicGravityConfig>,
    pub third_body: Option<ThirdBodyGravity>,
    pub solar_radiation_pressure: Option<SolarRadiationPressure>,
    pub earth_radiation_pressure: Option<EarthRadiationPressure>,
    pub relativity: Option<SchwarzschildRelativity>,
}
Additive force components for ForceModelKind::Composite.

Fields

two_body_mu_km3_s2: Option<f64>

Optional central two-body gravitational parameter, km^3/s^2.

zonal: Option<ZonalGravity>

Optional zonal gravity perturbation.

spherical_harmonic: Option<SphericalHarmonicGravityConfig>

Optional embedded EGM96 spherical-harmonic perturbation.

third_body: Option<ThirdBodyGravity>

Optional Sun and Moon third-body perturbation.

solar_radiation_pressure: Option<SolarRadiationPressure>

Optional cannonball solar radiation pressure perturbation.

earth_radiation_pressure: Option<EarthRadiationPressure>

Optional cannonball Earth albedo and infrared radiation pressure perturbation.

relativity: Option<SchwarzschildRelativity>

Optional geocentric Schwarzschild relativistic correction.

Implementations

Source

impl ForceModelComponents

pub const EMPTY: Self

No force components.

pub fn earth_two_body() -> Self

Canonical Earth two-body central gravity.

pub fn earth_phase_a( solar_radiation_pressure: Option<SolarRadiationPressure>, ) -> Self

Canonical Earth Phase A force set, with optional spacecraft SRP parameters.

pub fn earth_phase_b( max_degree: u16, max_order: u16, solar_radiation_pressure: Option<SolarRadiationPressure>, ) -> Result<Self, PropagationError>

Canonical Earth Phase B force set with embedded EGM96 harmonics.

pub fn with_two_body_mu(self, mu_km3_s2: f64) -> Self

Set or replace central two-body gravity.

pub fn with_zonal(self, zonal: ZonalGravity) -> Self

Set or replace zonal gravity.

pub fn with_spherical_harmonic( self, gravity: SphericalHarmonicGravityConfig, ) -> Self

Set or replace embedded EGM96 spherical-harmonic gravity.

pub fn with_third_body(self, third_body: ThirdBodyGravity) -> Self

Set or replace third-body gravity.

pub fn with_solar_radiation_pressure(self, srp: SolarRadiationPressure) -> Self

Set or replace solar radiation pressure.

pub fn with_earth_radiation_pressure( self, pressure: EarthRadiationPressure, ) -> Self

Set or replace Earth albedo and infrared radiation pressure.

pub fn with_relativity(self, relativity: SchwarzschildRelativity) -> Self

Set or replace relativity.