pub struct SpaceWeatherTable { /* private fields */ }Expand description
Time-indexed CelesTrak CSSI space-weather table.
Implementations
Sourceimpl SpaceWeatherTable
impl SpaceWeatherTable
Sourcepub fn days(&self) -> &[SpaceWeatherDay]
pub fn days(&self) -> &[SpaceWeatherDay]
All daily-resolution rows, sorted by date.
Sourcepub fn monthly(&self) -> &[SpaceWeatherDay]
pub fn monthly(&self) -> &[SpaceWeatherDay]
All monthly-predicted rows, sorted by date.
Sourcepub fn day(&self, year: i32, month: u8, day: u8) -> Option<&SpaceWeatherDay>
pub fn day(&self, year: i32, month: u8, day: u8) -> Option<&SpaceWeatherDay>
Row for a UTC civil date, including monthly holdover when applicable.
Sourcepub fn coverage(&self) -> SpaceWeatherCoverage
pub fn coverage(&self) -> SpaceWeatherCoverage
Summary of the dates covered by this table.
Sourcepub fn space_weather_at(
&self,
epoch_j2000_s: f64,
) -> Result<SpaceWeather, SpaceWeatherError>
pub fn space_weather_at( &self, epoch_j2000_s: f64, ) -> Result<SpaceWeather, SpaceWeatherError>
NRLMSISE-00 conventional space-weather inputs at an epoch.
epoch_j2000_s is treated as UT seconds on the same convention used by
the drag module for CartesianState::epoch_tdb_seconds; the TDB-UT
difference is below one minute against daily and 3-hour source data.
Sourcepub fn sample_at(
&self,
epoch_j2000_s: f64,
) -> Result<SpaceWeatherSample, SpaceWeatherError>
pub fn sample_at( &self, epoch_j2000_s: f64, ) -> Result<SpaceWeatherSample, SpaceWeatherError>
Lookup a sample with default policy, returning values plus row metadata.
Sourcepub fn sample_at_with_policy(
&self,
epoch_j2000_s: f64,
policy: SpaceWeatherPolicy,
) -> Result<SpaceWeatherSample, SpaceWeatherError>
pub fn sample_at_with_policy( &self, epoch_j2000_s: f64, policy: SpaceWeatherPolicy, ) -> Result<SpaceWeatherSample, SpaceWeatherError>
Lookup a sample with explicit row-class and geomagnetic-default policy.
Sourcepub fn ap_array_at(
&self,
epoch_j2000_s: f64,
) -> Result<ApArray, SpaceWeatherError>
pub fn ap_array_at( &self, epoch_j2000_s: f64, ) -> Result<ApArray, SpaceWeatherError>
Build the NRLMSISE-00 seven-element Ap history array at an epoch.