pub struct TcaFinderOptions {
pub coarse_step_seconds: f64,
pub time_tolerance_seconds: f64,
}Expand description
Options for find_tca_candidates and find_tca_candidates_from_tles.
Fields
coarse_step_seconds: f64Coarse sampling step used to bracket local range minima.
time_tolerance_seconds: f64Time tolerance to which each local range minimum is refined.