pub struct TcaWindow {
pub start: JulianDate,
pub end: JulianDate,
}Expand description
Absolute time window searched for TCA events.
Fields
start: JulianDateStart of the search window.
end: JulianDateEnd of the search window.
Implementations
Sourceimpl TcaWindow
impl TcaWindow
Sourcepub const fn new(start: JulianDate, end: JulianDate) -> Self
pub const fn new(start: JulianDate, end: JulianDate) -> Self
Build a TCA search window from absolute start and end Julian dates.
Sourcepub fn from_start_and_duration_seconds(
start: JulianDate,
duration_seconds: f64,
) -> Result<Self, TcaError>
pub fn from_start_and_duration_seconds( start: JulianDate, duration_seconds: f64, ) -> Result<Self, TcaError>
Build a TCA search window from a start Julian date and duration.