pub enum CarrierPhaseError {
EqualFrequencies,
InvalidFrequency,
InvalidObservation,
InvalidThreshold,
}Expand description
Error produced by carrier-phase scalar combinations.
Variants
EqualFrequencies
The denominator for a frequency combination is degenerate.
InvalidFrequency
Cycle-to-meter conversion requires a positive carrier frequency.
InvalidObservation
Observation values must be finite and produce finite combinations.
InvalidThreshold
Cycle-slip and smoothing thresholds must be finite and in range.