pub enum SlipReason {
Lli,
DataGap,
GeometryFree,
MelbourneWubbena,
}Expand description
Reason a carrier arc was split at an epoch.
Variants
Lli
Loss-of-lock indicator bit 0 was set on either band.
DataGap
Gap to the previous usable sample exceeded the configured threshold.
GeometryFree
Geometry-free phase step exceeded the configured threshold.
MelbourneWubbena
Melbourne-Wubbena step exceeded the configured wide-lane-cycle threshold.