pub enum DistributionSource {
Direct,
NasaCddis,
LocalFile,
InMemory,
}Expand description
Explicit distributor used to obtain an exact public product.
Distributor selection never changes product publisher, solution class, issue, cadence, date, or family.
Variants
Direct
The cataloged analysis-center or IGS direct archive.
NasaCddis
NASA CDDIS over HTTPS, optionally authenticated with Earthdata Login.
LocalFile
Bytes read from a caller-provided local file.
InMemory
Bytes supplied directly by the caller.
Implementations