pub const fn catalog() -> &'static [CenterCatalogEntry]Expand description
Static catalog entries, in the same order as the binding data catalog.
pub const fn catalog() -> &'static [CenterCatalogEntry]Static catalog entries, in the same order as the binding data catalog.