pub fn product_convention(
center: AnalysisCenter,
product_type: ProductType,
) -> Result<&'static CenterProductConvention, DataCatalogError>Expand description
Look up the convention for one center and product type.
pub fn product_convention(
center: AnalysisCenter,
product_type: ProductType,
) -> Result<&'static CenterProductConvention, DataCatalogError>Look up the convention for one center and product type.