pub struct ProductSpec {
pub center: AnalysisCenter,
pub product_type: ProductType,
pub date: ProductDate,
pub sample: String,
pub issue: Option<String>,
}Expand description
A pure product specification that resolves to one archive filename and URL.
Fields
center: AnalysisCenterAnalysis center.
product_type: ProductTypeProduct type.
date: ProductDateProduct date.
sample: StringSampling token.
issue: Option<String>Optional issue time for ultra-rapid products.
Implementations
Sourceimpl ProductSpec
impl ProductSpec
Sourcepub fn new(
center: AnalysisCenter,
product_type: ProductType,
date: ProductDate,
sample: &str,
issue: Option<&str>,
) -> Result<Self, DataCatalogError>
pub fn new( center: AnalysisCenter, product_type: ProductType, date: ProductDate, sample: &str, issue: Option<&str>, ) -> Result<Self, DataCatalogError>
Build a product specification and validate it against the catalog.
Sourcepub fn gps_week(&self) -> Result<u32, DataCatalogError>
pub fn gps_week(&self) -> Result<u32, DataCatalogError>
GPS week for the product date.
Sourcepub fn day_of_year(&self) -> u16
pub fn day_of_year(&self) -> u16
Day-of-year for the product date.
Sourcepub fn canonical_filename(&self) -> Result<String, DataCatalogError>
pub fn canonical_filename(&self) -> Result<String, DataCatalogError>
Canonical IGS long-name filename without archive compression suffix.
Sourcepub fn archive_url(&self) -> Result<String, DataCatalogError>
pub fn archive_url(&self) -> Result<String, DataCatalogError>
Full archive URL, including .gz when the cataloged archive is gzipped.