pub enum PreciseInterpolantStoreError {
Io {
path: PathBuf,
message: String,
},
Parse {
reason: String,
},
UnsupportedVersion {
version: u16,
},
UnsupportedTimeScale {
tag: u8,
},
UnsupportedSatelliteSystem {
tag: u8,
},
DuplicateSatellite {
sat: GnssSatelliteId,
},
Checksum {
expected: u64,
found: u64,
},
SatelliteChecksum {
sat: GnssSatelliteId,
expected: u64,
found: u64,
},
}Expand description
Errors from precise-interpolant store conversion, serialization, and open.
Variants
Io
File I/O failed.
Parse
Store bytes could not be parsed.
UnsupportedVersion
The store version is not supported.
UnsupportedTimeScale
The time-scale tag is not supported.
UnsupportedSatelliteSystem
The satellite-system tag is not supported.
DuplicateSatellite
A satellite appears more than once in the index.
Fields

sat: GnssSatelliteIdDuplicated satellite id.
Checksum
The file-level checksum did not match the bytes opened.
SatelliteChecksum
A satellite payload checksum did not match its index record.