OrbitState

Struct OrbitState 

pub struct OrbitState {
Show 25 fields pub a: f64, pub n0: f64, pub n: f64, pub tk: f64, pub mk: f64, pub eccentric_anomaly: f64, pub kepler_iterations: usize, pub sin_e: f64, pub cos_e: f64, pub nu: f64, pub phi: f64, pub s2: f64, pub c2: f64, pub du: f64, pub dr: f64, pub di: f64, pub u: f64, pub r: f64, pub i: f64, pub xp: f64, pub yp: f64, pub omega_k: f64, pub x_m: f64, pub y_m: f64, pub z_m: f64,
}
The full intermediate substrate of a broadcast orbit evaluation.

Every field is exposed so a 0-ULP parity test can localize a mismatch to a single operation. OrbitState::position returns the ECEF position.

Fields

a: f64

Semi-major axis (m).

n0: f64

Computed mean motion (rad/s).

n: f64

Corrected mean motion (rad/s).

tk: f64

Time from ephemeris reference epoch, half-week folded (s).

mk: f64

Mean anomaly (rad).

eccentric_anomaly: f64

Eccentric anomaly (rad).

kepler_iterations: usize

Number of Kepler iterations.

sin_e: f64

sin(E).

cos_e: f64

cos(E).

nu: f64

True anomaly (rad).

phi: f64

Argument of latitude before correction (rad).

s2: f64

sin(2*phi).

c2: f64

cos(2*phi).

du: f64

Argument-of-latitude correction (rad).

dr: f64

Radius correction (m).

di: f64

Inclination correction (rad).

u: f64

Corrected argument of latitude (rad).

r: f64

Corrected radius (m).

i: f64

Corrected inclination (rad).

xp: f64

Orbital-plane x (m).

yp: f64

Orbital-plane y (m).

omega_k: f64

Corrected longitude of ascending node (rad).

x_m: f64

ECEF x (m).

y_m: f64

ECEF y (m).

z_m: f64

ECEF z (m).

Implementations

Source

impl OrbitState

pub const fn position(&self) -> Result<ItrfPositionM, FrameValueError>

The Earth-fixed (ITRF/ECEF) satellite position in meters.