pub struct Sp3MergeInputIdentity {
pub schema_version: u8,
pub contributors: Vec<Sp3ArtifactIdentity>,
pub precedence_contributors: Option<Vec<Sp3ArtifactIdentity>>,
pub stable_id: String,
}Expand description
Canonical identity of a complete SP3 merge input set and merge policy.
Fields
schema_version: u8Canonical encoding version.
contributors: Vec<Sp3ArtifactIdentity>Contributors in canonical order, independent of caller enumeration.
precedence_contributors: Option<Vec<Sp3ArtifactIdentity>>Ordered contributors when precedence combination makes order semantic.
None for mean and median combination.
stable_id: StringVersioned SHA-256 identity of the contributors and complete merge policy.
Implementations
Sourceimpl Sp3MergeInputIdentity
impl Sp3MergeInputIdentity
Sourcepub fn new(
contributors: &[Sp3ArtifactIdentity],
policy: &MergeOptions,
) -> Result<Self, Sp3MergeInputIdentityError>
pub fn new( contributors: &[Sp3ArtifactIdentity], policy: &MergeOptions, ) -> Result<Self, Sp3MergeInputIdentityError>
Validate, canonically order, and bind all contributors and merge controls.
Sourcepub fn verify(
&self,
policy: &MergeOptions,
) -> Result<bool, Sp3MergeInputIdentityError>
pub fn verify( &self, policy: &MergeOptions, ) -> Result<bool, Sp3MergeInputIdentityError>
Recompute and verify this persisted identity and its merge controls.
Sourcepub fn verify_against(
&self,
contributors: &[Sp3ArtifactIdentity],
policy: &MergeOptions,
) -> Result<bool, Sp3MergeInputIdentityError>
pub fn verify_against( &self, contributors: &[Sp3ArtifactIdentity], policy: &MergeOptions, ) -> Result<bool, Sp3MergeInputIdentityError>
Recompute and compare against separately persisted contributor records and merge controls.