pub struct TrackRtsEpoch {
pub t_s: f64,
pub predicted: TrackState,
pub updated: TrackState,
pub transition_from_previous: Option<Vec<Vec<f64>>>,
}Expand description
One epoch in a recorded forward pass for track RTS smoothing.
Fields
t_s: f64Epoch in seconds in the caller’s monotonic time base.
predicted: TrackStatePredicted state before a correction at this epoch.
updated: TrackStateUpdated state after the correction, or the same as predicted for no update.
transition_from_previous: Option<Vec<Vec<f64>>>Transition from the previous updated epoch to this predicted epoch.
Implementations
Sourceimpl TrackRtsEpoch
impl TrackRtsEpoch
Sourcepub fn new(
predicted: TrackState,
updated: TrackState,
transition_from_previous: Option<Vec<Vec<f64>>>,
) -> Result<Self, TrackError>
pub fn new( predicted: TrackState, updated: TrackState, transition_from_previous: Option<Vec<Vec<f64>>>, ) -> Result<Self, TrackError>
Build and validate one recorded epoch.
Sourcepub fn validate(&self) -> Result<(), TrackError>
pub fn validate(&self) -> Result<(), TrackError>
Validate state frames, dimensions, covariance, and transition dimensions.