pub enum ExactCacheOpen {
Hit(CommittedExactCacheEntry),
Owner(ExactCacheOwner),
}Expand description
Result of opening an exact cache with single-flight coordination.
Variants
Hit(CommittedExactCacheEntry)
A complete committed entry was already available or was published by the owner observed while waiting.
Owner(ExactCacheOwner)
This process owns acquisition and is the only caller that should fetch.