pub fn identity_sha256(
identity: &ProductIdentity,
) -> Result<String, ExactCacheError>Expand description
Return the SHA-256 binding for every field of an exact product identity.
pub fn identity_sha256(
identity: &ProductIdentity,
) -> Result<String, ExactCacheError>Return the SHA-256 binding for every field of an exact product identity.