pub struct ExactCacheSingleFlightWait { /* private fields */ }Expand description
Target-neutral liveness state shared by filesystem and browser substrates.
Implementations
Sourceimpl ExactCacheSingleFlightWait
impl ExactCacheSingleFlightWait
Sourcepub fn observe(
&mut self,
now: Duration,
revision: &[u8],
options: ExactCacheSingleFlightOptions,
) -> Result<ExactCacheSingleFlightDecision, ExactCacheError>
pub fn observe( &mut self, now: Duration, revision: &[u8], options: ExactCacheSingleFlightOptions, ) -> Result<ExactCacheSingleFlightDecision, ExactCacheError>
Observe an opaque owner/heartbeat revision and select the next action.
now and the returned delay use a caller-local monotonic clock. The
revision must change whenever the owner token or heartbeat changes.