pub enum SerializableErrorStateLayout {
Fifteen,
TwentyOne,
}Expand description
Serializable error-state layout tag.
Variants
Fifteen
Fifteen-state layout dr, dv, psi, b_a, b_g.
TwentyOne
Twenty-one-state layout with accelerometer and gyroscope scale factors.
Implementations
Sourceimpl SerializableErrorStateLayout
impl SerializableErrorStateLayout
Sourcepub const fn from_native(layout: ErrorStateLayout) -> Self
pub const fn from_native(layout: ErrorStateLayout) -> Self
Convert a native layout into its stable serialized tag.
Sourcepub const fn to_native(self) -> ErrorStateLayout
pub const fn to_native(self) -> ErrorStateLayout
Convert the stable serialized tag back to the native layout.