pub struct SerializableNavState {
pub t_j2000_s: F64Bits,
pub position_ecef_m: [F64Bits; 3],
pub velocity_ecef_mps: [F64Bits; 3],
pub attitude_body_to_ecef: [[F64Bits; 3]; 3],
pub accel_bias_mps2: [F64Bits; 3],
pub gyro_bias_rps: [F64Bits; 3],
}Expand description
Serializable navigation state with exact floating-point bit storage.
Fields
t_j2000_s: F64BitsState time in seconds since J2000, stored as raw f64 bits.
position_ecef_m: [F64Bits; 3]IMU ECEF position in meters, stored as raw f64 bits.
velocity_ecef_mps: [F64Bits; 3]IMU ECEF velocity in meters per second, stored as raw f64 bits.
attitude_body_to_ecef: [[F64Bits; 3]; 3]Body-to-ECEF direction cosine matrix, stored as raw f64 bits.
accel_bias_mps2: [F64Bits; 3]Closed-loop accelerometer bias estimate, stored as raw f64 bits.
gyro_bias_rps: [F64Bits; 3]Closed-loop gyroscope bias estimate, stored as raw f64 bits.
Implementations
Sourcepub fn from_native(state: &NavState) -> Self
pub fn from_native(state: &NavState) -> Self
Convert a native navigation state into the stable serialized form.
Sourcepub fn to_native(&self) -> Result<NavState, FusionStateCodecError>
pub fn to_native(&self) -> Result<NavState, FusionStateCodecError>
Convert the stable serialized form back to a validated native state.