pub struct TightGnssObservation {
pub satellite_id: GnssSatelliteId,
pub pseudorange_m: f64,
pub pseudorange_sigma_m: f64,
pub range_rate: Option<TightRangeRateObservation>,
pub carrier_phase: Option<TightCarrierPhaseObservation>,
pub ionosphere_delay_m: f64,
pub troposphere_delay_m: f64,
}Expand description
Raw GNSS observation for one satellite in a tight update.
Fields
satellite_id: GnssSatelliteIdSatellite identifier.
pseudorange_m: f64Measured code pseudorange in meters.
pseudorange_sigma_m: f64One-sigma pseudorange uncertainty in meters.
range_rate: Option<TightRangeRateObservation>Optional Doppler-derived range-rate row.
carrier_phase: Option<TightCarrierPhaseObservation>Optional carrier-phase row using a supplied float ambiguity.
ionosphere_delay_m: f64Ionospheric group delay correction for code, in meters.
troposphere_delay_m: f64Tropospheric delay correction, in meters.
Implementations
Sourceimpl TightGnssObservation
impl TightGnssObservation
Sourcepub fn pseudorange(
satellite_id: GnssSatelliteId,
pseudorange_m: f64,
pseudorange_sigma_m: f64,
) -> Result<Self, FusionError>
pub fn pseudorange( satellite_id: GnssSatelliteId, pseudorange_m: f64, pseudorange_sigma_m: f64, ) -> Result<Self, FusionError>
Build a pseudorange-only observation.
Sourcepub fn validate(&self) -> Result<(), FusionError>
pub fn validate(&self) -> Result<(), FusionError>
Validate finite measurement values, positive sigmas, and optional rows.