pub enum GeodeticTimeSeriesError {
InvalidInput {
field: &'static str,
reason: &'static str,
},
TooFewSamples {
samples: usize,
needed: usize,
},
InsufficientPairs {
pairs: usize,
needed: usize,
},
SingularTrajectory,
DidNotConverge {
status: i32,
},
Solver(TrfError),
}Expand description
Error returned by geodetic time-series estimators.
Variants
InvalidInput
A boundary input was malformed.
Fields
TooFewSamples
There are fewer position samples than the estimator requires.
InsufficientPairs
MIDAS could not select enough usable dominant-period pairs.
SingularTrajectory
The trajectory design matrix is rank deficient.
DidNotConverge
The trust-region least-squares solver exhausted or stopped without satisfying a convergence condition.
Solver(TrfError)
The trust-region least-squares solver failed.