pub enum PositionFrame {
Enu,
Ecef {
reference: Wgs84Geodetic,
},
}Expand description
Coordinate frame of the supplied position samples.
Variants
Enu
Position vectors are local east, north, up coordinates in metres.
Ecef
Position vectors are ITRF/ECEF metres and are differenced from the supplied reference before rotation into local ENU.
Fields

reference: Wgs84GeodeticGeodetic reference position used to define the local ENU frame.