pub enum TimeSeriesQuality {
Nominal,
ShortSpan,
}Expand description
Qualitative strength of a time-series estimate.
Variants
Nominal
The series has at least one dominant period of span and enough selected pairs for the requested estimator.
ShortSpan
The estimate is usable but has less than three dominant periods of span, so MIDAS does not have its single-step robustness guarantee.