pub struct MotionField {
pub frame: NetworkFrame,
pub stations: Vec<StationMotion>,
pub common_mode_enu_m_per_yr: [f64; 3],
}Expand description
Network motion field.
Fields
frame: NetworkFrameOutput frame and filtering controls used for this field.
stations: Vec<StationMotion>Station motions in the same order as the accepted inputs.
common_mode_enu_m_per_yr: [f64; 3]Unweighted mean velocity removed from station rates, or zero when common-mode removal is disabled.