pub struct PositionSample {
pub epoch_year: f64,
pub position_m: [f64; 3],
pub covariance_m2: Option<[[f64; 3]; 3]>,
}Expand description
One position sample in a station time series.
Fields
epoch_year: f64Epoch expressed as a decimal year in a continuous time scale.
position_m: [f64; 3]Position vector in metres, interpreted by PositionFrame.
covariance_m2: Option<[[f64; 3]; 3]>Optional 3x3 coordinate covariance in square metres, in the same frame
as position_m.