pub struct DopOptions {
pub visibility: VisibilityOptions,
pub weighting: DopWeighting,
pub light_time: bool,
}Expand description
DOP planning options.
Fields
visibility: VisibilityOptionsVisibility scan options used when no explicit satellite list is supplied.
weighting: DopWeightingDOP row weighting policy.
light_time: boolApply light-time and Sagnac corrections when forming the line of sight.