pub struct ObservableMediaOptions<'a> {
pub troposphere: Option<ObservableTroposphereCorrection>,
pub ionosphere: Option<ObservableIonosphereCorrection<'a>>,
}Expand description
Optional media corrections for one predicted tracking observable.
Fields
troposphere: Option<ObservableTroposphereCorrection>Neutral-atmosphere slant delay to add to the range, if present.
ionosphere: Option<ObservableIonosphereCorrection<'a>>Ionospheric group delay to add to the range, if present.