pub enum ObservationQcError {
InvalidInterval,
InvalidGapFactor,
InvalidClockJumpThreshold,
}Expand description
Error returned when QC options are invalid.
Variants
InvalidInterval
The supplied nominal interval was zero, negative, or non-finite.
InvalidGapFactor
The supplied gap factor was not finite and greater than one.
InvalidClockJumpThreshold
The supplied clock-jump threshold was zero, negative, or non-finite.