pub struct SatelliteMultipathQc {
pub satellite: GnssSatelliteId,
pub mp1: Option<MpStats>,
pub mp2: Option<MpStats>,
}Expand description
Per-satellite multipath RMS after per-arc teqc moving-average filtering.
Fields
satellite: GnssSatelliteIdSatellite id.
mp1: Option<MpStats>MP1 RMS, when at least one complete sample was available.
mp2: Option<MpStats>MP2 RMS, when at least one complete sample was available.