fit

Function fit 

pub fn fit(
    samples: &[EcefSample],
    scale: TimeScale,
) -> Result<ReducedOrbit, ReducedOrbitError>
Fit the default circular_secular model to ECEF samples, with all epochs interpreted in scale (e.g. an SP3 product’s GPST).

samples are (epoch, ECEF meters); they are ordered by time, the earliest becomes the model epoch t0, each is converted ITRS->GCRS at the correct Earth orientation, and the five free elements (a, i, raan0, raan_rate, arg_lat0, n) are refined to minimize stacked GCRS position residuals.

Equivalent to fit_with_model with Model::CircularSecular.