pub enum StaticReferenceStationMode {
CodeDgnss,
CarrierFloat,
CarrierFixed,
}Expand description
High-level solve mode selected for the reported station coordinate.
Variants
CodeDgnss
Code-DGNSS corrected pseudoranges stacked through the static SPP solver.
CarrierFloat
Carrier RTK float baseline added to the surveyed reference coordinate.
CarrierFixed
Carrier RTK integer-fixed baseline added to the surveyed reference coordinate.