solve_static_reference_station_rinex

Function solve_static_reference_station_rinex 

pub fn solve_static_reference_station_rinex<S>(
    source: &S,
    reference_obs: &RinexObs,
    rover_obs: &RinexObs,
    reference_position_m: [f64; 3],
    options: &StaticReferenceStationRinexOptions,
) -> Result<StaticReferenceStationSolution, StaticReferenceStationError>
Solve one rover/reference-station coordinate from paired reference and rover RINEX observation files plus a known reference coordinate.

reference_position_m is the ECEF coordinate of the point represented by the reference observations. The returned coordinate is the corresponding point represented by the rover observations; caller-owned antenna marker/ARP conversions should be applied consistently before and after this call.