pub struct GalileoNequickCoeffs {
pub ai0: f64,
pub ai1: f64,
pub ai2: f64,
}Expand description
Galileo broadcast NeQuick-G ionosphere coefficients (ai0, ai1, ai2).
Galileo navigation messages broadcast these three coefficients to drive the effective ionisation level used by the Galileo single-frequency ionosphere correction. They are distinct from GPS/BeiDou Klobuchar alpha/beta values.
Fields
ai0: f64Constant effective-ionisation coefficient.
ai1: f64Linear MODIP coefficient.
ai2: f64Quadratic MODIP coefficient.