pub struct SppDopplerSolution {
pub receiver: ReceiverSolution,
pub velocity: Option<VelocitySolution>,
pub velocity_error: Option<VelocityError>,
}Expand description
Result from solving position and, when possible, Doppler velocity together.
Fields
receiver: ReceiverSolutionReceiver position solution. rx_clock_drift_s_s is populated when
velocity is Some.
velocity: Option<VelocitySolution>Solved ECEF velocity and clock drift. None when no Doppler rows were
supplied or the velocity system was not solvable.
velocity_error: Option<VelocityError>Velocity-solve failure when Doppler rows were present but not solvable.