pub struct StaticReferenceStationSolution {
pub mode: StaticReferenceStationMode,
pub fix_status: StaticReferenceFixStatus,
pub position: ItrfPositionM,
pub geodetic: Option<Wgs84Geodetic>,
pub covariance: StaticReferenceStationCovariance,
pub baseline_vector_m: [f64; 3],
pub baseline_m: f64,
pub code_solution: Option<StaticReferenceCodeSolution>,
pub carrier_solution: Option<StaticReferenceCarrierSolution>,
pub mode_reports: Vec<StaticReferenceModeReport>,
pub diagnostics: Vec<StaticReferenceEpochDiagnostic>,
}Expand description
Final station solution returned by the RINEX wrapper.
Fields
mode: StaticReferenceStationModeSelected mode used for the reported coordinate.
fix_status: StaticReferenceFixStatusReported fix status for the selected coordinate.
position: ItrfPositionMSolved rover/reference-station coordinate.
geodetic: Option<Wgs84Geodetic>Geodetic coordinate when requested.
covariance: StaticReferenceStationCovariancePosition covariance for the reported coordinate.
baseline_vector_m: [f64; 3]Baseline vector, rover minus reference, metres.
baseline_m: f64Baseline length, metres.
code_solution: Option<StaticReferenceCodeSolution>Code-DGNSS solution detail when the mode was enabled and solved.
carrier_solution: Option<StaticReferenceCarrierSolution>Carrier RTK solution detail when the mode was enabled and solved.
mode_reports: Vec<StaticReferenceModeReport>Per-mode attempt reports.
diagnostics: Vec<StaticReferenceEpochDiagnostic>Diagnostics for the selected mode.