pub struct StaticSolutionMetadata {
pub iterations: usize,
pub converged: bool,
pub status: Status,
pub outer_iterations: usize,
pub final_robust_scale_m: Option<f64>,
pub used_measurements: usize,
pub n_parameters: usize,
pub redundancy: isize,
}Expand description
Metadata describing the static solve.
Fields
iterations: usizeNumber of accepted trust-region iterations in the final inner solve.
converged: boolWhether the final inner solve reached a convergence criterion.
status: StatusThe final inner solver termination status.
outer_iterations: usizeNumber of robust outer iterations performed.
final_robust_scale_m: Option<f64>Final MAD robust scale in meters, when robust reweighting ran.
used_measurements: usizeNumber of measurements used by the final solve.
n_parameters: usizeNumber of fitted state parameters.
redundancy: isizeDegrees of freedom, used_measurements - n_parameters.