pub struct EpochVectorCorrection {
pub epoch_index: usize,
pub vector_m: [f64; 3],
}Expand description
Indexed vector result. The epoch index refers to the input epoch slice.
Fields
epoch_index: usizevector_m: [f64; 3]Trait Implementations
Sourceimpl Clone for EpochVectorCorrection
impl Clone for EpochVectorCorrection
Sourcefn clone(&self) -> EpochVectorCorrection
fn clone(&self) -> EpochVectorCorrection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for EpochVectorCorrection
Sourceimpl Debug for EpochVectorCorrection
impl Debug for EpochVectorCorrection
Sourceimpl PartialEq for EpochVectorCorrection
impl PartialEq for EpochVectorCorrection
Sourcefn eq(&self, other: &EpochVectorCorrection) -> bool
fn eq(&self, other: &EpochVectorCorrection) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EpochVectorCorrection