pub struct PppCorrectionObservation {
pub sat: GnssSatelliteId,
pub freq1_hz: f64,
pub freq2_hz: f64,
pub glonass_channel: Option<i8>,
}Expand description
One satellite observation row needed by the static correction precompute.
Fields
sat: GnssSatelliteIdfreq1_hz: f64freq2_hz: f64glonass_channel: Option<i8>Trait Implementations
Sourceimpl Clone for PppCorrectionObservation
impl Clone for PppCorrectionObservation
Sourcefn clone(&self) -> PppCorrectionObservation
fn clone(&self) -> PppCorrectionObservation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PppCorrectionObservation
Sourceimpl Debug for PppCorrectionObservation
impl Debug for PppCorrectionObservation
Sourceimpl PartialEq for PppCorrectionObservation
impl PartialEq for PppCorrectionObservation
Sourcefn eq(&self, other: &PppCorrectionObservation) -> bool
fn eq(&self, other: &PppCorrectionObservation) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PppCorrectionObservation