pub struct SatScalarCorrection {
pub sat: GnssSatelliteId,
pub epoch_index: usize,
pub value_m: f64,
}Expand description
Indexed satellite scalar result. The epoch index refers to the input epoch slice.
Fields
sat: GnssSatelliteIdepoch_index: usizevalue_m: f64Trait Implementations
Sourceimpl Clone for SatScalarCorrection
impl Clone for SatScalarCorrection
Sourcefn clone(&self) -> SatScalarCorrection
fn clone(&self) -> SatScalarCorrection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SatScalarCorrection
impl Debug for SatScalarCorrection
Sourceimpl PartialEq for SatScalarCorrection
impl PartialEq for SatScalarCorrection
Sourcefn eq(&self, other: &SatScalarCorrection) -> bool
fn eq(&self, other: &SatScalarCorrection) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SatScalarCorrection