pub struct SatVectorCorrection {
pub sat: GnssSatelliteId,
pub epoch_index: usize,
pub vector_m: [f64; 3],
}Expand description
Indexed satellite vector result. The epoch index refers to the input epoch slice.
Fields
sat: GnssSatelliteIdepoch_index: usizevector_m: [f64; 3]Trait Implementations
Sourceimpl Clone for SatVectorCorrection
impl Clone for SatVectorCorrection
Sourcefn clone(&self) -> SatVectorCorrection
fn clone(&self) -> SatVectorCorrection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SatVectorCorrection
impl Debug for SatVectorCorrection
Sourceimpl PartialEq for SatVectorCorrection
impl PartialEq for SatVectorCorrection
Sourcefn eq(&self, other: &SatVectorCorrection) -> bool
fn eq(&self, other: &SatVectorCorrection) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SatVectorCorrection