pub enum CycleSlipError {
InvalidConfig(CycleSlipConfigError),
NonFiniteObservation,
NonFiniteEpochTime,
EpochsNotOrdered,
InvalidFrequency,
EqualFrequencies,
}Expand description
Error produced while evaluating a cycle-slip detector sample.
Variants
InvalidConfig(CycleSlipConfigError)
Detector configuration failed validation.
NonFiniteObservation
One or more observation scalars were not finite.
NonFiniteEpochTime
A supplied epoch time was not finite.
EpochsNotOrdered
Supplied epoch times were not ordered.
InvalidFrequency
One or both carrier frequencies were not positive and finite.
EqualFrequencies
The two carrier frequencies were too close for a wide-lane combination.