pub enum TecError {
Show 16 variants
NonFiniteObservation,
InvalidShellHeight,
InvalidEarthRadius,
InvalidFrequency,
EqualFrequencies,
InvalidReceiverLatitude,
InvalidReceiverLongitude,
InvalidElevation,
InvalidAzimuth,
NonFiniteTec,
EmptyArc,
NoEpochs,
NoObservations,
NonFiniteEpochTime,
EpochsNotOrdered,
InsufficientArcSamples,
}Expand description
Error produced while estimating dual-frequency TEC.
Variants
NonFiniteObservation
One or more observation scalars were not finite.
InvalidShellHeight
The configured shell height was not positive and finite.
InvalidEarthRadius
The configured Earth radius was not positive and finite.
InvalidFrequency
One or both carrier frequencies were not positive and finite.
EqualFrequencies
The two carrier frequencies were too close to form a TEC denominator.
InvalidReceiverLatitude
Receiver geodetic latitude was not finite or not in [-pi/2, pi/2].
InvalidReceiverLongitude
Receiver geodetic longitude was not finite.
InvalidElevation
Elevation was not finite or not in [0, pi/2].
InvalidAzimuth
Azimuth was not finite.
NonFiniteTec
A supplied TEC value was not finite.
EmptyArc
The supplied continuous arc had no samples.
NoEpochs
The input epoch stream had no epochs.
NoObservations
The input epoch stream contained no satellite observations.
NonFiniteEpochTime
An epoch time was not finite.
EpochsNotOrdered
Epoch times were not ordered.
InsufficientArcSamples
A satellite arc did not contain enough samples for leveling.