pub struct IonosphericPiercePoint {
pub latitude_rad: f64,
pub longitude_rad: f64,
pub latitude_deg: f64,
pub longitude_deg: f64,
pub earth_central_angle_rad: f64,
pub shell_height_m: f64,
}Expand description
Ionospheric pierce point on the configured thin shell.
Fields
latitude_rad: f64Pierce-point geodetic latitude, in radians.
longitude_rad: f64Pierce-point geodetic longitude normalized to [-pi, pi), in radians.
latitude_deg: f64Pierce-point geodetic latitude, in degrees.
longitude_deg: f64Pierce-point geodetic longitude normalized to [-180, 180), in degrees.
earth_central_angle_rad: f64Earth-central angle from receiver to pierce point, in radians.
shell_height_m: f64Shell height used for the pierce point, in meters.