pub enum RinexClockError {
MalformedAsRecord {
line: usize,
reason: &'static str,
record: String,
},
BadField {
line: usize,
field: &'static str,
value: String,
},
InvalidInput {
field: &'static str,
reason: &'static str,
},
}Expand description
RINEX clock parse error.
Variants
MalformedAsRecord
An AS satellite clock row is too short to carry the required bias.
Fields
BadField
A required AS field could not be parsed or was out of range.
Fields
InvalidInput
Public manual input or query parameter was invalid.