pub enum FrameSkipReason {
Truncated,
Malformed(String),
}Expand description
Typed reason for a skipped CRC-valid frame.
Variants
Truncated
The body ended before all required fields of its recognized type.
Malformed(String)
The body is internally inconsistent for its recognized type.