pub fn message_number(body: &[u8]) -> Result<u16>Expand description
Read the 12-bit RTCM message number from the start of a message body.
Returns crate::Error::Parse if the body is shorter than 12 bits.
pub fn message_number(body: &[u8]) -> Result<u16>Read the 12-bit RTCM message number from the start of a message body.
Returns crate::Error::Parse if the body is shorter than 12 bits.