pub struct FrameSkip {
pub offset: usize,
pub message_number: Option<u16>,
pub reason: FrameSkipReason,
}Expand description
One CRC-valid frame that could not be decoded.
Fields
offset: usizeByte offset of the frame preamble in the scanned buffer.
message_number: Option<u16>RTCM message number when the body was long enough to carry one.
reason: FrameSkipReasonWhy the body did not decode.