GpsEphemeris

Struct GpsEphemeris 

pub struct GpsEphemeris {
Show 30 fields pub satellite_id: u8, pub week_number: u16, pub sv_accuracy: u8, pub code_on_l2: u8, pub idot: i32, pub iode: u8, pub t_oc: u16, pub a_f2: i16, pub a_f1: i32, pub a_f0: i32, pub iodc: u16, pub c_rs: i32, pub delta_n: i32, pub m0: i64, pub c_uc: i32, pub eccentricity: u64, pub c_us: i32, pub sqrt_a: u64, pub t_oe: u16, pub c_ic: i32, pub omega0: i64, pub c_is: i32, pub i0: i64, pub c_rc: i32, pub omega: i64, pub omega_dot: i32, pub t_gd: i16, pub sv_health: u8, pub l2_p_data_flag: bool, pub fit_interval: bool,
}
A decoded GPS broadcast ephemeris (message 1019).

Angular quantities are in semicircles (scale noted per field), harmonic correction terms in radians, distances in meters, and clock terms in seconds, each recovered by multiplying the raw integer by its scale factor.

Fields

satellite_id: u8

GPS satellite PRN (DF009).

week_number: u16

GPS week number (DF076, 10 bits).

sv_accuracy: u8

SV accuracy / URA index (DF077, 4 bits).

code_on_l2: u8

Code on L2 (DF078, 2 bits).

idot: i32

Rate of inclination angle IDOT (DF079, int14, scale 2^-43 semicircles/s).

iode: u8

Issue of data, ephemeris (DF071, 8 bits).

t_oc: u16

Clock data reference time t_oc (DF081, uint16, scale 2^4 s).

a_f2: i16

Clock drift rate a_f2 (DF082, int8, scale 2^-55 s/s^2).

a_f1: i32

Clock drift a_f1 (DF083, int16, scale 2^-43 s/s).

a_f0: i32

Clock bias a_f0 (DF084, int22, scale 2^-31 s).

iodc: u16

Issue of data, clock (DF085, 10 bits).

c_rs: i32

Orbit-radius sine correction C_rs (DF086, int16, scale 2^-5 m).

delta_n: i32

Mean-motion difference dn (DF087, int16, scale 2^-43 semicircles/s).

m0: i64

Mean anomaly at reference time M_0 (DF088, int32, scale 2^-31 semicircles).

c_uc: i32

Latitude-argument cosine correction C_uc (DF089, int16, scale 2^-29 rad).

eccentricity: u64

Eccentricity e (DF090, uint32, scale 2^-33).

c_us: i32

Latitude-argument sine correction C_us (DF091, int16, scale 2^-29 rad).

sqrt_a: u64

Square root of the semi-major axis sqrt(A) (DF092, uint32, scale 2^-19).

t_oe: u16

Ephemeris reference time t_oe (DF093, uint16, scale 2^4 s).

c_ic: i32

Inclination cosine correction C_ic (DF094, int16, scale 2^-29 rad).

omega0: i64

Longitude of ascending node Omega_0 (DF095, int32, scale 2^-31 semicircles).

c_is: i32

Inclination sine correction C_is (DF096, int16, scale 2^-29 rad).

i0: i64

Inclination at reference time i_0 (DF097, int32, scale 2^-31 semicircles).

c_rc: i32

Orbit-radius cosine correction C_rc (DF098, int16, scale 2^-5 m).

omega: i64

Argument of perigee omega (DF099, int32, scale 2^-31 semicircles).

omega_dot: i32

Rate of right ascension Omega-dot (DF100, int24, scale 2^-43 semicircles/s).

t_gd: i16

Group delay differential t_GD (DF101, int8, scale 2^-31 s).

sv_health: u8

SV health (DF102, 6 bits).

l2_p_data_flag: bool

L2 P-data flag (DF103).

fit_interval: bool

Fit-interval flag (DF137).

Implementations

Source

impl GpsEphemeris

pub fn satellite(&self) -> Result<GnssSatelliteId>

The satellite identifier for this ephemeris.

pub fn decode(body: &[u8]) -> Result<Self>

Decode a message 1019 body (without the transport frame).

pub fn encode(&self) -> Vec<u8>

Encode this GPS ephemeris body (without the transport frame).