pub struct StreamDiagnostics {
pub resync_bytes: usize,
pub skipped_frames: Vec<FrameSkip>,
}Expand description
Diagnostics collected while scanning an RTCM byte stream.
Fields
resync_bytes: usizeBytes skipped while resynchronizing on the next valid frame.
skipped_frames: Vec<FrameSkip>CRC-valid frames whose body could not be decoded into the message IR.