pub struct DualCycleSlipEpoch {
pub epoch_sort_key: String,
pub gap_time_s: Option<f64>,
pub base_observations: Vec<DualCycleSlipObservation>,
pub rover_observations: Vec<DualCycleSlipObservation>,
}Expand description
One dual-frequency RTK epoch for cycle-slip preprocessing.
Fields
epoch_sort_key: StringCaller-provided deterministic epoch ordering key.
gap_time_s: Option<f64>Comparable epoch coordinate in seconds, when the caller can supply one.
base_observations: Vec<DualCycleSlipObservation>rover_observations: Vec<DualCycleSlipObservation>Trait Implementations
Sourceimpl Clone for DualCycleSlipEpoch
impl Clone for DualCycleSlipEpoch
Sourcefn clone(&self) -> DualCycleSlipEpoch
fn clone(&self) -> DualCycleSlipEpoch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DualCycleSlipEpoch
impl Debug for DualCycleSlipEpoch
Sourceimpl PartialEq for DualCycleSlipEpoch
impl PartialEq for DualCycleSlipEpoch
Sourcefn eq(&self, other: &DualCycleSlipEpoch) -> bool
fn eq(&self, other: &DualCycleSlipEpoch) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DualCycleSlipEpoch