pub struct DeclaredScenarioSource<'a, E: ?Sized> { /* private fields */ }Expand description
Already loaded ephemeris source paired with its scenario identity.
Implementations
Sourceimpl<'a, E: ?Sized> DeclaredScenarioSource<'a, E>
impl<'a, E: ?Sized> DeclaredScenarioSource<'a, E>
Sourcepub fn new(source: &'a E, identity: ScenarioExternalProduct) -> Self
pub fn new(source: &'a E, identity: ScenarioExternalProduct) -> Self
Pair an in-memory ephemeris source with the identity declared by a scenario.
Sourcepub fn identity(&self) -> &ScenarioExternalProduct
pub fn identity(&self) -> &ScenarioExternalProduct
Declared identity for this source.