pub struct ScenarioExternalProduct {
pub kind: ScenarioExternalProductKind,
pub product_id: String,
pub content_digest: String,
}Expand description
Stable identity of an external product named by a scenario.
Fields
kind: ScenarioExternalProductKindExternal product class.
product_id: StringCaller-controlled stable product identifier, such as a catalog path or name.
content_digest: StringCore-verified content fingerprint string for the supplied product.
Implementations