pub struct SyntheticTermArrays {Show 25 fields
pub geometric_range_m: Vec<f64>,
pub satellite_clock_m: Vec<f64>,
pub receiver_clock_m: Vec<f64>,
pub satellite_clock_error_m: Vec<f64>,
pub ionosphere_m: Vec<f64>,
pub troposphere_m: Vec<f64>,
pub thermal_noise_m: Vec<f64>,
pub multipath_m: Vec<f64>,
pub quantization_m: Vec<f64>,
pub carrier_phase_geometric_cycles: Vec<f64>,
pub carrier_phase_receiver_clock_cycles: Vec<f64>,
pub carrier_phase_satellite_clock_cycles: Vec<f64>,
pub carrier_phase_satellite_clock_error_cycles: Vec<f64>,
pub carrier_phase_ionosphere_cycles: Vec<f64>,
pub carrier_phase_troposphere_cycles: Vec<f64>,
pub carrier_phase_thermal_noise_cycles: Vec<f64>,
pub carrier_phase_bias_cycles: Vec<f64>,
pub carrier_phase_quantization_cycles: Vec<f64>,
pub doppler_satellite_motion_hz: Vec<f64>,
pub doppler_receiver_motion_hz: Vec<f64>,
pub doppler_satellite_clock_hz: Vec<f64>,
pub doppler_receiver_clock_hz: Vec<f64>,
pub doppler_satellite_clock_error_hz: Vec<f64>,
pub doppler_thermal_noise_hz: Vec<f64>,
pub doppler_quantization_hz: Vec<f64>,
}Expand description
Per-observation ground-truth term arrays.
Fields
geometric_range_m: Vec<f64>Geometric range in meters.
satellite_clock_m: Vec<f64>Nominal ephemeris satellite-clock contribution in meters.
receiver_clock_m: Vec<f64>Receiver-clock contribution in meters.
satellite_clock_error_m: Vec<f64>Injected satellite-clock contribution in meters.
ionosphere_m: Vec<f64>Ionospheric code delay in meters.
troposphere_m: Vec<f64>Tropospheric delay in meters.
thermal_noise_m: Vec<f64>Thermal code noise in meters.
multipath_m: Vec<f64>Specular code multipath in meters.
quantization_m: Vec<f64>Core quantization contribution in meters. This is zero before explicit serialization.
carrier_phase_geometric_cycles: Vec<f64>Carrier geometric range contribution in cycles.
carrier_phase_receiver_clock_cycles: Vec<f64>Carrier receiver-clock contribution in cycles.
carrier_phase_satellite_clock_cycles: Vec<f64>Carrier nominal satellite-clock contribution in cycles.
carrier_phase_satellite_clock_error_cycles: Vec<f64>Carrier injected satellite-clock contribution in cycles.
carrier_phase_ionosphere_cycles: Vec<f64>Carrier ionosphere contribution in cycles.
carrier_phase_troposphere_cycles: Vec<f64>Carrier troposphere contribution in cycles.
carrier_phase_thermal_noise_cycles: Vec<f64>Carrier thermal-noise contribution in cycles.
carrier_phase_bias_cycles: Vec<f64>Constant carrier-phase ambiguity contribution in cycles.
carrier_phase_quantization_cycles: Vec<f64>Core carrier quantization contribution in cycles. This is zero before explicit serialization.
doppler_satellite_motion_hz: Vec<f64>Doppler contribution from satellite line-of-sight motion in hertz.
doppler_receiver_motion_hz: Vec<f64>Doppler contribution from receiver line-of-sight motion in hertz.
doppler_satellite_clock_hz: Vec<f64>Doppler contribution from nominal ephemeris satellite-clock rate in hertz.
doppler_receiver_clock_hz: Vec<f64>Doppler contribution from receiver-clock rate in hertz.
doppler_satellite_clock_error_hz: Vec<f64>Doppler contribution from injected satellite-clock rate in hertz.
doppler_thermal_noise_hz: Vec<f64>Doppler thermal-noise contribution in hertz.
doppler_quantization_hz: Vec<f64>Core Doppler quantization contribution in hertz. This is zero before explicit serialization.
Implementations
Sourceimpl SyntheticTermArrays
impl SyntheticTermArrays
Sourcepub fn pseudorange_sum_m(&self, index: usize) -> Option<f64>
pub fn pseudorange_sum_m(&self, index: usize) -> Option<f64>
Sum the pseudorange terms for one observation in the generator order.
Sourcepub fn carrier_phase_sum_cycles(&self, index: usize) -> Option<f64>
pub fn carrier_phase_sum_cycles(&self, index: usize) -> Option<f64>
Sum the carrier-phase terms for one observation in the generator order.
Sourcepub fn doppler_sum_hz(&self, index: usize) -> Option<f64>
pub fn doppler_sum_hz(&self, index: usize) -> Option<f64>
Sum the Doppler terms for one observation in the generator order.