pub enum SiderealTemplateMethod {
Mean,
RobustMad,
Ewma {
alpha: f64,
},
}Expand description
Template estimator used by sidereal_filter.
Variants
Mean
Arithmetic mean of the prior values in the same phase bin.
RobustMad
MAD-gated mean of the prior values in the same phase bin.
Ewma
Exponentially weighted mean of prior values in the same phase bin.