pub struct MultipathEnvelopePoint {
pub delay_chips: f64,
pub delay_s: f64,
pub in_phase_chips: f64,
pub in_phase_s: f64,
pub in_phase_m: f64,
pub anti_phase_chips: f64,
pub anti_phase_s: f64,
pub anti_phase_m: f64,
pub running_average_chips: f64,
pub running_average_s: f64,
pub running_average_m: f64,
}Expand description
Multipath envelope value at one reflected-path delay.
Fields
delay_chips: f64Reflected-path delay relative to the direct path, in code chips.
delay_s: f64Reflected-path delay relative to the direct path, in seconds.
in_phase_chips: f64In-phase multipath tracking error, in code chips.
in_phase_s: f64In-phase multipath tracking error, in seconds.
in_phase_m: f64In-phase multipath tracking error, in metres.
anti_phase_chips: f64Anti-phase multipath tracking error, in code chips.
anti_phase_s: f64Anti-phase multipath tracking error, in seconds.
anti_phase_m: f64Anti-phase multipath tracking error, in metres.
running_average_chips: f64Running average of the absolute envelope, in code chips.
running_average_s: f64Running average of the absolute envelope, in seconds.
running_average_m: f64Running average of the absolute envelope, in metres.