pub enum SourceSolveMode {
Toa,
Tdoa {
reference_sensor: usize,
},
}Expand description
Measurement model used by locate_source.
Variants
Toa
Absolute time of arrival. The state is [position..., origin_time].
Tdoa
Time difference of arrival against a reference sensor.
The residual subtracts the reference sensor equation and does not solve an origin-time state. The returned origin time is estimated after the position solve from the absolute arrivals.