pub enum SsrReferencePoint {
AntennaPhaseCenter,
CenterOfMass,
}Expand description
Reference point of the corrected orbit.
rtcm_ssr_default preserves the convention used by the current correction
path: no satellite PCO is applied because the corrected state is treated as
an antenna-phase-center state unless the caller explicitly selects CoM.
igs_ssr_default selects CoM for IGS SSR CoM streams. IGS SSR v1.00 defines
CoM/APC as the satellite reference point choices and IGS RTS product
documentation identifies CoM streams separately from antenna-reference
streams:
https://files.igs.org/pub/data/format/igs_ssr_v1.pdf
https://igs.org/rts/products/
Variants
Implementations
Sourceimpl SsrReferencePoint
impl SsrReferencePoint
Sourcepub const fn rtcm_ssr_default() -> Self
pub const fn rtcm_ssr_default() -> Self
Default reference point for decoded RTCM SSR streams.
Sourcepub const fn igs_ssr_default() -> Self
pub const fn igs_ssr_default() -> Self
Default reference point for IGS SSR CoM streams.
Sourcepub const fn from_tag(tag: u8) -> Option<Self>
pub const fn from_tag(tag: u8) -> Option<Self>
Decode a compact tag produced by SsrReferencePoint::tag.