pub struct SsrCorrectionStore { /* private fields */ }Expand description
Active SSR corrections keyed by satellite.
Implementations
Sourceimpl SsrCorrectionStore
impl SsrCorrectionStore
Sourcepub fn with_reference_point(self, reference_point: OrbitReferencePoint) -> Self
pub fn with_reference_point(self, reference_point: OrbitReferencePoint) -> Self
Set the orbit reference point policy for later ingests.
Sourcepub fn with_staleness(self, policy: StalenessPolicy) -> Self
pub fn with_staleness(self, policy: StalenessPolicy) -> Self
Set the store staleness policy.
Sourcepub fn staleness(&self) -> StalenessPolicy
pub fn staleness(&self) -> StalenessPolicy
The store-level staleness policy.
Sourcepub fn ingest(&mut self, message: &Message, week: GnssWeekTow) -> Result<()>
pub fn ingest(&mut self, message: &Message, week: GnssWeekTow) -> Result<()>
Ingest one RTCM message, ignoring non-SSR messages.
Sourcepub fn ingest_ssr(
&mut self,
message: &SsrMessage,
week: GnssWeekTow,
) -> Result<()>
pub fn ingest_ssr( &mut self, message: &SsrMessage, week: GnssWeekTow, ) -> Result<()>
Ingest one decoded RTCM SSR message.
Sourcepub fn orbit(&self, sat: GnssSatelliteId) -> Option<&SsrOrbitCorrection>
pub fn orbit(&self, sat: GnssSatelliteId) -> Option<&SsrOrbitCorrection>
Orbit correction for a satellite.
Sourcepub fn clock(&self, sat: GnssSatelliteId) -> Option<&SsrClockCorrection>
pub fn clock(&self, sat: GnssSatelliteId) -> Option<&SsrClockCorrection>
Clock correction for a satellite.
Sourcepub fn ura_index(&self, sat: GnssSatelliteId) -> Option<u8>
pub fn ura_index(&self, sat: GnssSatelliteId) -> Option<u8>
URA index for a satellite.
Sourcepub fn code_bias(&self, sat: GnssSatelliteId, signal: u8) -> Option<f64>
pub fn code_bias(&self, sat: GnssSatelliteId, signal: u8) -> Option<f64>
Code bias in meters for a satellite and raw signal id.
Sourcepub fn phase_bias(&self, sat: GnssSatelliteId, signal: u8) -> Option<f64>
pub fn phase_bias(&self, sat: GnssSatelliteId, signal: u8) -> Option<f64>
Phase bias for a satellite.