pub enum TerrainStoreError {
Io {
path: PathBuf,
message: String,
},
Parse {
reason: String,
},
UnsupportedVersion {
version: u16,
},
UnsupportedDatum {
tag: u8,
},
DuplicateTile {
lat_index: i32,
lon_index: i32,
},
Checksum {
lat_index: i32,
lon_index: i32,
expected: u64,
found: u64,
},
}Expand description
Errors from terrain store conversion, serialization, and parsing.
Variants
Io
File or directory I/O failed.
Parse
DTED or terrain store bytes could not be parsed.
UnsupportedVersion
The terrain store version is not supported.
UnsupportedDatum
The terrain store datum tag is not supported.
DuplicateTile
Two input DTED files resolved to the same integer tile id.
Checksum
A tile payload checksum did not match its index record.