pub enum VelocityObservable {
RangeRate,
Doppler,
}Expand description
Observation value convention for solve.
Variants
RangeRate
Observation values are pseudorange rates in meters per second.
Doppler
Observation values are Doppler shifts in hertz and will be converted
with the observation’s carrier_hz.