pub struct TimeTables<'a> {
pub leap_seconds: &'a [LeapSecondEntry],
pub ut1_utc: &'a [Ut1Entry],
}Expand description
Caller-supplied time tables for UTC, TAI, TT, UT1, TCG, TDB, and TCB.
Fields
leap_seconds: &'a [LeapSecondEntry]Leap-second table entries with the same shape as the embedded table.
ut1_utc: &'a [Ut1Entry]UT1-UTC samples with the same shape as the embedded table.
Implementations
Sourceimpl<'a> TimeTables<'a>
impl<'a> TimeTables<'a>
Sourcepub fn new(
leap_seconds: &'a [LeapSecondEntry],
ut1_utc: &'a [Ut1Entry],
) -> Result<Self, CoverageError>
pub fn new( leap_seconds: &'a [LeapSecondEntry], ut1_utc: &'a [Ut1Entry], ) -> Result<Self, CoverageError>
Construct time tables from caller-owned slices.
Sourcepub fn leap_second_table(&self) -> LeapSecondTable
pub fn leap_second_table(&self) -> LeapSecondTable
Provenance and coverage for this leap-second table.
Sourcepub fn ut1_coverage(&self) -> Ut1Provenance
pub fn ut1_coverage(&self) -> Ut1Provenance
Coverage for this UT1-UTC table, expressed on the TT axis.
Sourceimpl TimeTables<'static>
impl TimeTables<'static>