Canonical GNSS carrier-frequency table.
All GNSS carrier lookup paths route through this module so signal frequency policy cannot drift between combinations, RINEX observation decoding, SPP, and ionosphere models.
Structs
- Carrier
Frequency - One fixed-frequency carrier-table entry.
- Carrier
Pair - A standard two-carrier ionosphere-free pair.
Enums
- Carrier
Band - GNSS carrier band.
Functions
- default_
iono_ free_ pair - Standard dual-frequency ionosphere-free carrier pair for a constellation.
- default_
spp_ carrier - Single-frequency carrier used by the SPP ionosphere-scaling policy.
- default_
spp_ frequency_ hz - Single-frequency carrier frequency used by the SPP ionosphere-scaling policy.
- fixed_
carrier_ frequencies - Fixed-frequency carrier entries. GLONASS FDMA carriers are channel-derived
through
rinex_band_frequency_hzand therefore do not appear here. - frequency_
hz - Carrier frequency in hertz for a constellation and canonical carrier band.
- glonass_
g1_ frequency_ hz - GLONASS G1 FDMA carrier frequency in hertz for an FDMA channel number
k. - iono_
free_ carrier_ frequencies - Carrier entries used by the current ionosphere-free public API.
- rinex_
band_ frequency_ hz - RINEX observation band frequency in hertz for a system and band digit.
- rinex_
band_ wavelength_ m - RINEX observation band wavelength in meters for a system and band digit.
- rinex_
observation_ frequency_ hz - RINEX observation-code frequency in hertz for a system and full code.
- rinex_
observation_ wavelength_ m - RINEX observation-code wavelength in meters for a system and full code.
- wavelength_
m - Carrier wavelength in meters for a constellation and canonical carrier band.