pub fn source_dop(
sensors: &[Sensor],
source_position_m: &[f64],
propagation_speed_m_s: f64,
) -> Result<Dop, SourceLocalizationError>Expand description
Compute timing DOP for a proposed source location.
The returned position DOP values multiply timing sigma in seconds to produce metres. The local Cartesian axes are used for the horizontal and vertical split.